@@ -1,5 +1,4 @@
-import sys
-
+from . import _typing
 from ._connection import (
     FakeRedis,
     FakeStrictRedis,
@@ -10,22 +9,10 @@ from .aioredis import (
     FakeRedis as FakeAsyncRedis,
     FakeConnection as FakeAsyncConnection,
 )
-
-if sys.version_info >= (3, 11):
-    from ._tcp_server import TcpFakeServer
-else:
-
-    class TcpFakeServer:
-        def __init__(self, *args, **kwargs):
-            raise NotImplementedError("TcpFakeServer is only available in Python 3.11+")
+from ._tcp_server import TcpFakeServer
 
 
-try:
-    from importlib import metadata
-except ImportError:  # for Python < 3.8
-    import importlib_metadata as metadata  # type: ignore
-
-__version__ = metadata.version("fakeredis")
+__version__ = _typing.lib_version
 __author__ = "Daniel Moran"
 __maintainer__ = "Daniel Moran"
 __email__ = "daniel@moransoftware.ca"
